<?php
/**
 * Plugin Name: 		Emage Hover Effects for Elementor
 * Plugin URI:  		https://imagehoverpro.blocksera.com
 * Author: 				20script
 * Author URI:			https://www.20script.ir
 * Description: 		Unlimited image hover effects to your web pages using this Elementor addon.
 * Version:     		4.2.0
 * Requires at least:   4.6
 * Tested up to:        5.4.1
 * License: 			GPL v3
 * Text Domain: 		ehe-lang
 * Domain Path: 		/languages
**/

if (!defined('ABSPATH')) {
    exit;
}

define('EHE_VERSION', '4.2.0');
define('EHE_MINIMUM_ELEMENTOR_VERSION', '1.1.2');
define('EHE_MINIMUM_PHP_VERSION', '5.4');
define('EHE_PATH', plugin_dir_path(__FILE__));
define('EHE_URL', plugin_dir_url(__FILE__));

require(EHE_PATH . 'includes/updater.php');

class Emage_Hover_Effects {

    private static $_instance = null;

    public static function get_instance() {
        if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
    }

    public function __construct() {
        $this->config = array(
            'license' => 'false',
            'license_key' => ''
        );
        $this->options = array();

        $this->options['config'] = array_merge($this->config, get_option('ehe_config', array()));

        add_action('plugins_loaded', [$this, 'init']);
        $this->updater = new Blocksera_Updater(__FILE__, 'emage-hover-effects-for-elementor', '4NymbyYaJ2VaExZbeLbN', $this->options['config']['license_key']);
    }
    
    public function init() {

        // Check if Elementor installed and activated
		if (!did_action('elementor/loaded')) {
			add_action('admin_notices', [$this, 'admin_notice_missing_main_plugin']);
			return;
        }
        
        // Check for required Elementor version
		if (!version_compare(ELEMENTOR_VERSION, EHE_MINIMUM_ELEMENTOR_VERSION, '>=')) {
			add_action('admin_notices', [$this, 'admin_notice_minimum_elementor_version']);
			return;
        }
        
        // Check for required PHP version
		if (version_compare(PHP_VERSION, EHE_MINIMUM_PHP_VERSION, '<') ) {
			add_action('admin_notices', [$this, 'admin_notice_minimum_php_version']);
			return;
		}
		
		add_action( 'elementor/editor/after_enqueue_scripts', function() {
            wp_register_script('eihe-admin-editor', EHE_URL . 'assets/js/editor.js', array(), EHE_VERSION, true);
            wp_localize_script('eihe-admin-editor', 'emage', array('ajax_url' => admin_url('admin-ajax.php')));
            wp_enqueue_script('eihe-admin-editor');
        });
        
        add_action('wp_ajax_emage_license', array($this, 'check_license'));
        add_action('elementor/frontend/after_enqueue_styles', array($this, 'includes'));
        add_action('elementor/frontend/after_register_scripts', array($this, 'scripts'));
		add_action('elementor/widgets/widgets_registered', array($this, 'register_widgets'));
		add_action( 'elementor/controls/controls_registered', array($this, 'register_controls'));
	}

	public function  register_controls() {
        if (!class_exists('Elementor_RepeatSelect_Control')) {
            require_once EHE_PATH . 'includes/repeatselect-control.php';
            $controls_manager = \Elementor\Plugin::$instance->controls_manager;
            $controls_manager->register_control('repeatselect', new \Elementor\Elementor_RepeatSelect_Control());
        }
        if (!class_exists('Elementor_Html5Sortable_Control')) {
            require_once EHE_PATH . 'includes/html5sortable-control.php';
            $controls_manager = \Elementor\Plugin::$instance->controls_manager;
            $controls_manager->register_control('html5sortable', new \Elementor\Elementor_Html5Sortable_Control());
        }
    }

    public function register_widgets() {
        require_once(EHE_PATH . 'widgets/emage-hover.php');
        require_once(EHE_PATH . 'widgets/emage-post-grid.php');
    }

    public function includes() {
		wp_enqueue_style('eihe-front-style', EHE_URL . 'assets/css/style.min.css', array(), EHE_VERSION);
    }

    public function scripts() {
        wp_register_script('emage', EHE_URL . 'assets/js/script.js', array('jquery'), EHE_VERSION, true);
    }

    public function admin_notice_missing_main_plugin() {

		if (isset($_GET['activate'])) unset($_GET['activate']);

		$message = sprintf(
			esc_html__('%1$s requires %2$s to be installed and activated.', 'emage-hover-effects-for-elementor' ),
			'<strong>' . esc_html__('Emage Hover Effects for Elementor', 'emage-hover-effects-for-elementor') . '</strong>',
			'<strong>' . esc_html__('Elementor', 'emage-hover-effects-for-elementor') . '</strong>'
		);

		printf('<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message);

    }
    
    public function admin_notice_minimum_elementor_version() {

		if (isset($_GET['activate'])) unset($_GET['activate']);

		$message = sprintf(
			esc_html__('%1$s requires %2$s version %3$s or greater.', 'emage-hover-effects-for-elementor'),
			'<strong>' . esc_html__('Emage Hover Effects for Elementor', 'emage-hover-effects-for-elementor') . '</strong>',
			'<strong>' . esc_html__('Elementor', 'emage-hover-effects-for-elementor') . '</strong>',
			EHE_MINIMUM_ELEMENTOR_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );

    }
    
    public function admin_notice_minimum_php_version() {

		if (isset($_GET['activate'])) unset($_GET['activate']);

		$message = sprintf(
			esc_html__('%1$s requires %2$s version %3$s or greater.', 'emage-hover-effects-for-elementor'),
			'<strong>' . esc_html__('Emage Hover Effects for Elementor', 'emage-hover-effects-for-elementor') . '</strong>',
			'<strong>' . esc_html__('PHP', 'emage-hover-effects-for-elementor') . '</strong>',
			EHE_MINIMUM_PHP_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );

    }
    
    public function check_license() {

        $license_action = sanitize_key($_POST['license_action']);
        $this->options['config']['license_key'] = sanitize_key($_POST['code']);

        $response = array(
            'message' => __('Your purchase code is not valid. Please try again.', 'ehe-lang')
        );

        switch ($license_action) {

            case 'activate':

                $queryargs = array(
                    'code' => $this->options['config']['license_key']
                );

                $update = $this->updater->request_info($queryargs);

                if ($update->license_error == 'limit_exceeded') {
                    $response['message'] = __('You have already used this code on another site.<br><br>Please deactivate license from the site or buy another license', 'ehe-lang');
                } else if ($update->license != 'false') {
                    $response['message'] = __('Emage Hover Effects has been activated.<br><br>Please update and refresh this page.', 'ehe-lang');
                }

                $this->options['config']['license'] = $update->license;

                break;

            case 'deactivate':

                $queryargs = array(
                    'code' => $this->options['config']['license_key'],
                    'remove' => 'true'
                );

                $update = $this->updater->request_info($queryargs);

                if ($update->license_error == 'site_removed') {

                    $response['message'] = __('Your license has been removed from this site. It can now be used again.<br><br>Please update and refresh this page', 'ehe-lang');
                    $this->options['config']['license_key'] = '';
                    $this->options['config']['license'] = $update->license;

                } else {
                    $response['message'] = __('Your purchase code is not valid. Please try again.', 'ehe-lang');
                }

                break;
        }

        $response['license'] = $this->options['config']['license'];
        update_option('ehe_config', $this->options['config']);
        wp_send_json($response);
    }
    
}

Emage_Hover_Effects::get_instance();

?>